@@ -143,11 +143,13 @@ def get_existing_keywords(googleads_client,customer_id):
         'camp_name': list(),
         'camp_id': list(),
         'camp_status': list(),
+        'camp_experiment_type': list(),
         'adgroup_name': list(),
         'adgroup_status': list(),
         'adgroup_id': list(),
         'keyword_name': list(),
         'keyword_type': list(),
+        'keyword_status': list(),
     }
     ga_service = googleads_client.get_service("GoogleAdsService")
     query = """
@@ -158,11 +160,13 @@ def get_existing_keywords(googleads_client,customer_id):
           campaign.id,
           campaign.name,
           campaign.status,
+          campaign.experiment_type,
           ad_group_criterion.type,
           ad_group_criterion.status,
           ad_group_criterion.criterion_id,
           ad_group_criterion.keyword.text,
-          ad_group_criterion.keyword.match_type
+          ad_group_criterion.keyword.match_type,
+          ad_group_criterion.status
         FROM ad_group_criterion       
         WHERE ad_group_criterion.type = KEYWORD AND campaign.status IN ('ENABLED', 'PAUSED')"""
 
@@ -185,11 +189,13 @@ def get_existing_keywords(googleads_client,customer_id):
         camps['camp_name'].append(row.campaign.name)
         camps['camp_id'].append(row.campaign.id)
         camps['camp_status'].append(row.campaign.status.name)
+        camps['camp_experiment_type'].append(row.campaign.experiment_type.name)
         camps['adgroup_name'].append(row.ad_group.name)
         camps['adgroup_id'].append(row.ad_group.id)
         camps['adgroup_status'].append(row.ad_group.status.name)
         camps['keyword_name'].append(keyword.text)
         camps['keyword_type'].append(keyword.match_type.name)
+        camps['keyword_status'].append(ad_group_criterion.status.name)
     df = pd.DataFrame(camps)
     return df
 
@@ -403,6 +409,39 @@ def get_all_shared_sets(client,customer_id):
     df = pd.DataFrame(df_dict)
     return df
 
+def get_shared_set_keywords(client,customer_id,shared_set_id):
+    df_dict = {
+        "shared_set_id": list(),
+        "shared_criterion_id": list(),
+        "shared_criterion_keyword_type": list(),
+        "shared_criterion_keyword_text": list(),
+    }
+
+    query = f"""
+    SELECT 
+    shared_set.id,
+    shared_criterion.criterion_id, 
+    shared_criterion.keyword.match_type, 
+    shared_criterion.keyword.text 
+    FROM shared_criterion 
+    WHERE shared_set.id = {shared_set_id} 
+    """
+
+    ga_service = client.get_service("GoogleAdsService")
+    search_request = client.get_type("SearchGoogleAdsStreamRequest")
+    search_request.customer_id = customer_id
+    search_request.query = query
+    stream = ga_service.search_stream(search_request)
+    
+    for batch in stream:
+        for row in batch.results:
+            df_dict['shared_set_id'].append(row.shared_set.id)
+            df_dict['shared_criterion_id'].append(row.shared_criterion.criterion_id)
+            df_dict['shared_criterion_keyword_text'].append(row.shared_criterion.keyword.text)
+            df_dict['shared_criterion_keyword_type'].append(row.shared_criterion.keyword.match_type.name)
+    
+    df = pd.DataFrame(df_dict)
+    return df
 
 def get_all_ads(client,customer_id):
     query = """
