@@ -513,7 +513,7 @@ def make_request(keyword, email, api_key):
         location_name="United States",
         keyword=keyword,
         priority=2,
-        depth=2,
+        depth=5,
         max_crawl_pages=2,
         tag=f"{keyword} google",
     )
@@ -527,23 +527,23 @@ def make_request(keyword, email, api_key):
               (response["status_code"], response["status_message"]))
 
 
-def make_live_request(keyword, email, api_key):
+def make_live_request(keyword, email, api_key,priority = 2, depth = 2, max_crawl_pages = 2):
     client = RestClient(email, api_key)
     post_data = dict()
     post_data[len(post_data)] = dict(
         language_name="English",
         location_name="United States",
         keyword=keyword,
-        priority=2,
-        depth=2,
-        max_crawl_pages=2,
+        priority=priority,
+        depth=depth,
+        max_crawl_pages=max_crawl_pages,
         tag=f"{keyword} google",
     )
     response = client.post(
         "/v3/serp/google/organic/live/advanced", post_data)
     if response["status_code"] == 20000:
         print('please wait for sometime.. till we gather data')
-        return(response, response['tasks'][0]['id'])
+        return response
     else:
         print("error. Code: %d Message: %s" %
               (response["status_code"], response["status_message"]))
