@@ -5,8 +5,10 @@ from google.ads.googleads.client import GoogleAdsClient
 from google.ads.googleads.errors import GoogleAdsException
 from sentence_transformers import SentenceTransformer
 from autoads.models import get_similarity_api
-from autoads.gads import (add_negative_keywords, get_existing_keywords,get_search_term_report,get_all_ads,create_ad,
-                        create_keyword,_handle_googleads_exception,create_adgroup, get_all_shared_sets)
+from autoads.gads import (add_negative_keywords, get_existing_keywords,
+                        get_search_term_report,get_all_ads,create_ad,
+                        create_keyword,_handle_googleads_exception,
+                        create_adgroup, get_all_shared_sets,get_shared_set_keywords)
 
 
 save_path = 'data' #all the csvs will be stored on this folder
@@ -30,8 +32,7 @@ keywords_to_remove = df_existing[df_existing['camp_status'].isin(['ENABLED'])]['
 print("Getting search term report")
 df_search_term_report = get_search_term_report(googleads_client,customer_id,start_date,end_date)
 # df_search_term_report = pd.read_csv('data/search_term_df.csv')
-df_search_term_report = df_search_term_report[df_search_term_report['campaign_status'].isin(['ENABLED']) &
-                                              df_search_term_report['adgroup_status'].isin(['ENABLED'])]
+df_search_term_report = df_search_term_report[df_search_term_report['campaign_status'].isin(['ENABLED'])]
 df_search_term_report['sum_conversion'] = df_search_term_report.groupby('date')['metrics_conversions'].transform(sum)
 df_search_term_report_negative = df_search_term_report.loc[df_search_term_report['sum_conversion']==0]
 df_search_term_report_negative = df_search_term_report_negative.drop_duplicates("stv_search_term")
@@ -179,6 +180,10 @@ if len(df_search_term_report) != 0:
 else:
     print("No keywords to add into existing campaigns")
 
+# path = '/home/maunish/Upwork Projects/Google-Ads-Project/examples/google-ads.yaml'
+# customer_id = '6554081276' # google ads customer id
+# googleads_client = GoogleAdsClient.load_from_storage(path=path, version="v9")
+
 if len(df_search_term_report_negative) != 0:
     print("Calculating similarity")
     model = SentenceTransformer(similarity_model_path)
@@ -197,19 +202,25 @@ if len(df_search_term_report_negative) != 0:
                 print(f"{i} - {row['shared_set_id']} - {row['shared_set_name']}")
             answer = int(input("Select the number from above list: "))
             shared_set_id = df_shared_set.loc[i].at['shared_set_id']
+            df_exclude = get_shared_set_keywords(googleads_client,customer_id,shared_set_id)
+            exclude_keywords = df_exclude['shared_criterion_keyword_text'].unique().tolist()
             negative_keywords = df_search_term_report_negative['stv_search_term'].unique().tolist()
-            resourse_names_list1 = add_negative_keywords(googleads_client,customer_id,shared_set_id,negative_keywords,kw_type='PHRASE')
-            resourse_names_list2 = add_negative_keywords(googleads_client,customer_id,shared_set_id,negative_keywords,kw_type='EXACT')
+            negative_keywords = [x for x in negative_keywords if x not in exclude_keywords]
+            if len(negative_keywords) != 0:
+                resourse_names_list1 = add_negative_keywords(googleads_client,customer_id,shared_set_id,negative_keywords,kw_type='PHRASE')
+                resourse_names_list2 = add_negative_keywords(googleads_client,customer_id,shared_set_id,negative_keywords,kw_type='EXACT')
 
-            keyword_ids1 = [x.resource_name.split('~')[-1] for x in resourse_names_list1]
-            keyword_ids2 = [x.resource_name.split('~')[-1] for x in resourse_names_list2]
+                keyword_ids1 = [x.resource_name.split('~')[-1] for x in resourse_names_list1]
+                keyword_ids2 = [x.resource_name.split('~')[-1] for x in resourse_names_list2]
 
-            info_dict['campaign_id'].extend(len(keyword_ids1)*"-")
-            info_dict['adgroup_id'].extend(len(keyword_ids1)*"-")
-            info_dict['shared_set_id'].extend(len(keyword_ids1)*[shared_set_id])
-            info_dict['keyword_id'].extend(keyword_ids1)
-            info_dict['keyword_id2'].extend(keyword_ids2)
-            info_dict['type'].extend(len(keyword_ids1)*"negative")
+                info_dict['campaign_id'].extend(len(keyword_ids1)*["-"])
+                info_dict['adgroup_id'].extend(len(keyword_ids1)*["-"])
+                info_dict['shared_set_id'].extend(len(keyword_ids1)*[str(shared_set_id)])
+                info_dict['keyword_id'].extend(keyword_ids1)
+                info_dict['keyword_id2'].extend(keyword_ids2)
+                info_dict['type'].extend(len(keyword_ids1)*["negative"])
+            else:
+                print("No keywords to add in negative list")
     else:
         print("No keywords to add in negative list")
 else:
