@@ -1,4 +1,5 @@
-# commit
+from operator import index
+import pandas as pd
 from client import RestClient
 task_type = [
     'organic',
@@ -42,23 +43,24 @@ def make_request(keyword, email='gpxfbhbgssdqcncbat@bvhrs.com', api_key='239f87a
               (response["status_code"], response["status_message"]))
 
 
-def make_live_request(keyword, email='gpxfbhbgssdqcncbat@bvhrs.com', api_key='239f87a1b59018ed'):
+def make_live_request(keyword, priority = 2, depth = 2, max_crawl_pages = 2, email='gpxfbhbgssdqcncbat@bvhrs.com', api_key='239f87a1b59018ed'):
     client = RestClient(email, api_key)
     post_data = dict()
     post_data[len(post_data)] = dict(
         language_name="English",
         location_name="United States",
         keyword=keyword,
-        priority=2,
-        depth=2,
-        max_crawl_pages=2,
+        priority=priority,
+        depth=depth,
+        max_crawl_pages=max_crawl_pages,
         tag=f"{keyword} google",
     )
     response = client.post(
         "/v3/serp/google/organic/live/advanced", post_data)
     if response["status_code"] == 20000:
         print('please wait for sometime.. till we gather data')
-        return(response, response['tasks'][0]['id'])
+        # return(response, response['tasks'][0]['id'])
+        return response
     else:
         print("error. Code: %d Message: %s" %
               (response["status_code"], response["status_message"]))
@@ -82,14 +84,19 @@ def get_response(uuid, res_type):
 
 
 def get_results(results, tasks, task_params):
-    df = {}
+    df = {
+        'organic_url' : list(),
+        'organic_description' : list(),
+        'organic_extended_people_also_search' : list(),
+        
+    }
     for i, data in enumerate(results['tasks'][0]['result'][0]['items']):
         task = data['type']
         if task == 'organic' and task in tasks:
             # [url, description, extended_people_also_search]
             for key in data.keys():
                 if key in task_params[f'{task}']:
-                    df[f'{task}_{key}'] = str(data[f'{key}'])
+                    df[f'{task}_{key}'].append(str(data[f'{key}']))
 
         if task == 'people_also_ask' and task in tasks:
             all_items = {f'{task}_{param}': list()
@@ -144,3 +151,17 @@ def get_results(results, tasks, task_params):
             df.update(all_items)
 
     return df
+
+if __name__ == '__main__':
+    key_list = ['ARR Loans', 'Revenue Based Loans', 'Loans for SaaS Companies']
+    for i,key in enumerate(key_list):
+        df_key = get_results(
+            make_live_request(
+                key, 
+                depth = 5, 
+                max_crawl_pages = 3, 
+                email='itjoxwtysgqxyqngln@kvhrs.com', 
+                api_key='3cfdfaa70b396144'),
+            tasks=task_type, task_params=task_params)
+        df_key = pd.DataFrame.from_dict(df_key)
+        df_key.to_csv(f'{key}_SERP.csv', index = False)
